@@ -3,7 +3,7 @@
 """ Graffl Tokenizer """
 
 
-from fast_sentence_tokenize.datablock import FindDictionaries
+from fast_sentence_tokenize.dmo import DictionaryFinder
 
 
 class TokenizeUseGraffl(object):
@@ -29,6 +29,11 @@ class TokenizeUseGraffl(object):
                 https://github.com/craigtrim/fast-sentence-tokenize/issues/1
             *   handle lingering squotes
                 https://github.com/craigtrim/fast-sentence-tokenize/issues/2
+        Updated:
+            27-Feb-2023
+            craigtrim@gmail.com
+            *   fix tokenization issue with squotes
+                https://github.com/craigtrim/fast-sentence-tokenize/issues/7
         """
         pass
 
@@ -38,9 +43,9 @@ class TokenizeUseGraffl(object):
         def transform(token: str) -> list:
             if "'" not in token:
                 return [token]
-            if token not in FindDictionaries.enclitics():
+            if token not in DictionaryFinder.enclitics():
                 return [token]
-            return FindDictionaries.enclitics()[token]
+            return DictionaryFinder.enclitics()[token]
 
         normalized = []
         for token in tokens:
@@ -62,9 +67,9 @@ class TokenizeUseGraffl(object):
                                  tokens: list) -> list:
 
         def transform(token: str) -> str:
-            if token not in FindDictionaries.abbreviations():
+            if token not in DictionaryFinder.abbreviations():
                 return token
-            return FindDictionaries.abbreviations()[token]
+            return DictionaryFinder.abbreviations()[token]
 
         return [transform(x) for x in tokens]
 
@@ -115,6 +120,10 @@ class TokenizeUseGraffl(object):
             if len(tokens[i]) > 1 and tokens[i].strip().endswith("'"):
                 squotes_suffix.append(i)
 
+        # fast-sentence-tokenize/issues/7; for tokens ending with an apostrophe (genitive form)
+        if not len(squotes_pos):
+            return tokens
+
         # the issue does not exist
         if not squotes_suffix:
             return tokens
@@ -170,11 +179,9 @@ class TokenizeUseGraffl(object):
                     if i + 2 < token_len:
                         return token[i + 2]
 
-                p2 = get_p2()
                 p1 = get_p1()
                 ch = token[i]
                 n1 = get_n1()
-                n2 = get_n2()
 
                 # fast-sentence-tokenize#1; keep underscored entities together
                 if ch.isalpha() or ch.isnumeric() or ch in [' ', '_']:
